@@ -2,6 +2,17 @@
 
 namespace panda { namespace time {
 
+bool _from_env (char* lzname, const char* envar) {
+    const char* val = getenv(envar);
+    if (val == NULL) return false;
+    size_t len = strlen(val);
+    if (len < 1 || len > TZNAME_MAX) return false;
+    strcpy(lzname, val);
+    return true;
+}
+
+bool _tz_lzname (char* lzname);
+
 #ifdef PTIME_OSTYPE_UNIX
 #  include "unix.h"
 #elif defined PTIME_OSTYPE_VMS
@@ -12,13 +23,9 @@ namespace panda { namespace time {
 #  error "Should not be here"
 #endif
 
-bool _from_env (char* lzname, const char* envar) {
-    const char* val = getenv(envar);
-    if (val == NULL) return false;
-    size_t len = strlen(val);
-    if (len < 1 || len > TZNAME_MAX) return false;
-    strcpy(lzname, val);
-    return true;
+void tz_lzname (char* lzname) {
+    if (_from_env(lzname, "TZ") || _tz_lzname(lzname)) return;
+	strcpy(lzname, PTIME_GMT_FALLBACK);
 }
 
 };};
